#include <QtWidgets> // for Qt functions
#include "Viewer.h" // PoLAR::Viewer header
#include "Image.h"
#include <iostream>
#include <QApplication>
#include <osg/Geode>
#include <osg/Geometry>
#include <osgDB/ReadFile>
#include <osgUtil/SmoothingVisitor>
#include <osgUtil/Optimizer>
#include <osg/io_utils>

#include "MyViewer3D.h"
#include "Util.h"

int main(int argc,char ** argv)
{


// Create the Qt application
QApplication app(argc, argv);
// Create the Qt widget, with no parent and a name
PoLAR::Viewer viewer(0, "MyVerySimpleViewer");
// Resize the widget
int width = 640;
int height = 480;
viewer.resize(width, height);

//Using OSG smart pointers
osg::ref_ptr<PoLAR::Image<unsigned char> > myImage;
// Open the image
myImage = new PoLAR::Image<unsigned char>("table.jpg", true);
// Resize the widget according to the size of the image read
width = myImage->getWidth();
height = myImage->getHeight();
viewer.resize(width, height);
// Add the image read as background image
viewer.setBgImage(myImage);
// Show it
viewer.bgImageOn();

// Load a projection matrix
osg::Matrixd P = PoLAR::Util::
readProjectionMatrix("matrice.txt");
viewer.setProjection(P);

// Load a 3D model
osg::ref_ptr<osg::Node> wine = osgDB::
readNodeFile("wine_bottle.3ds");
osgUtil::SmoothingVisitor smooth;
osgUtil::Optimizer optimizer;
optimizer.optimize(wine.get());
wine->accept(smooth);

// Add the loaded model to the scene
PoLAR::Object3D *obj = new PoLAR::Object3D
(wine.get(), true);
viewer.addObject3D(obj);

obj->setEditOn();
obj->translate(14,3,0);
obj->scale(2);
obj->setEditOff();

//Affichage
viewer.show();
app.connect( &app, SIGNAL(lastWindowClosed()
), &app, SLOT(quit()) );
return app.exec();
}